@@ -2,15 +2,7 @@ use serde_derive::Deserialize;
 use serde_derive::Serialize;
 use serde_json::Value;
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Customers {
-    pub object: String,
-    pub url: String,
-    #[serde(rename = "has_more")]
-    pub has_more: bool,
-    pub data: Vec<Customer>,
-}
+
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
@@ -105,92 +97,6 @@ pub struct Metadata {
 }
 
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Charges {
-    pub object: String,
-    pub url: String,
-    #[serde(rename = "has_more")]
-    pub has_more: bool,
-    pub data: Vec<Charge>,
-}
-
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Charge {
-    pub id: String,
-    pub object: String,
-    pub amount: i64,
-    #[serde(rename = "amount_captured")]
-    pub amount_captured: i64,
-    #[serde(rename = "amount_refunded")]
-    pub amount_refunded: i64,
-    #[serde(rename = "balance_transaction")]
-    pub balance_transaction: String,
-    #[serde(rename = "billing_details")]
-    pub billing_details: BillingDetails,
-    pub captured: bool,
-    pub created: i64,
-    pub currency: String,
-    pub description: String,
-    pub disputed: bool,
-    #[serde(rename = "fraud_details")]
-    pub fraud_details: FraudDetails,
-    pub livemode: bool,
-    pub metadata: Metadata,
-    pub paid: bool,
-    #[serde(rename = "payment_method")]
-    pub payment_method: String,
-    #[serde(rename = "payment_method_details")]
-    pub payment_method_details: PaymentMethodDetails,
-    #[serde(rename = "receipt_url")]
-    pub receipt_url: String,
-    pub refunded: bool,
-    pub refunds: Refunds,
-    pub status: String,
-    // #[serde(rename = "calculated_statement_descriptor")]
-    // pub calculated_statement_descriptor: Value,
-    // pub customer: Value,
-    // pub invoice: Value,
-    // #[serde(rename = "failure_code")]
-    // pub failure_code: Value,
-    // #[serde(rename = "failure_message")]
-    // pub failure_message: Value,
-    // #[serde(rename = "on_behalf_of")]
-    // pub on_behalf_of: Value,
-    // pub order: Value,
-    // pub outcome: Value,
-    // #[serde(rename = "payment_intent")]
-    // pub payment_intent: Value,
-    // #[serde(rename = "receipt_email")]
-    // pub receipt_email: Value,
-    // #[serde(rename = "receipt_number")]
-    // pub receipt_number: Value,
-    // pub review: Value,
-    // pub shipping: Value,
-    // #[serde(rename = "source_transfer")]
-    // pub source_transfer: Value,
-    // #[serde(rename = "statement_descriptor")]
-    // pub statement_descriptor: Value,
-    // #[serde(rename = "statement_descriptor_suffix")]
-    // pub statement_descriptor_suffix: Value,
-    // #[serde(rename = "transfer_data")]
-    // pub transfer_data: Value,
-    // #[serde(rename = "transfer_group")]
-    // pub transfer_group: Value,
-    // pub application: Value,
-    // #[serde(rename = "application_fee")]
-    // pub application_fee: Value,
-    // #[serde(rename = "application_fee_amount")]
-    // pub application_fee_amount: Value,
-}
-
-
-
-
-
-
-
 
 
 
@@ -216,18 +122,9 @@ pub struct Address {
     pub state: Option<String>,
 }
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct FraudDetails {
-}
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct PaymentMethodDetails {
-    pub card: Card,
-    #[serde(rename = "type")]
-    pub type_field: String,
-}
+
+
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
@@ -260,15 +157,6 @@ pub struct Checks {
     pub cvc_check: String,
 }
 
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
-#[serde(rename_all = "camelCase")]
-pub struct Refunds {
-    pub object: String,
-    // pub data: Vec<Value>,
-    #[serde(rename = "has_more")]
-    pub has_more: bool,
-    pub url: String,
-}
 
 #[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
